Tell Me About Your Sweater!
1 | sweater(design, fiber)
|
design |
This character is the name of the sweater design |
fiber |
This character is the fiber you used to knit your sweater (ie alpaca) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.