Description Usage
View source: R/theme_wacky.R
This theme adds some wacky effects to your data visualization. If you want your eyeballs to bleed, choose this theme!
1
theme_wacky()
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.