yarn: Knitting for Friends

Description Usage Arguments

View source: R/yarn.R

Description

This is a function that tells a friend what you would knit them using the yarn yardage you have!

Usage

1
yarn(friend_name, yarn_yardage)

Arguments

friend_name

This is a character argument that is your friend's name

yarn_yardage

This is a number that tells you yarn yardage


scoutcleonard/yarn documentation built on Dec. 22, 2021, 11:11 p.m.