This is a function that tells a friend what you would knit them using the yarn yardage you have!
1 | yarn(friend_name, yarn_yardage)
|
friend_name |
This is a character argument that is your friend's name |
yarn_yardage |
This is a number that tells you yarn yardage |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.